<?php
/**
 * Template for displaying Comments.
 *
 * The area of the page that contains both current comments
 * and the comment form. The actual display of comments is
 * handled by a callback to aplos_comment() which is
 * located in the inc/template-tags.php file.
 *
 * @package Aplos
 * @since Aplos 1.0.0
 */
?>
 
<?php
    //return early if user is unregistered and password is required
    if ( post_password_required() )
        return;
?>
 
    <div id="comments" class="comments-area">
 
    <?php if ( have_comments() ) : ?>
        <h2 class="comments-title">
            <?php
                printf( _n( '1 комментарий', '%1$s комментариев', get_comments_number(), 'aplos' ),
                    number_format_i18n( get_comments_number() ), '<span>' . get_the_title() . '</span>' );
            ?>
        </h2>
 
        <?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // are there comments to navigate through? If so, show navigation ?>
        <nav role="navigation" id="comment-nav-above" class="site-navigation comment-navigation">
            <h1 class="assistive-text"><?php _e( 'Навигация', 'aplos' ); ?></h1>
            <div class="nav-previous"><?php previous_comments_link( __( '&larr; Предыдущие комментарии', 'aplos' ) ); ?></div>
            <div class="nav-next"><?php next_comments_link( __( 'Следующие комментарии &rarr;', 'aplos' ) ); ?></div>
        </nav><!-- #comment-nav-before .site-navigation .comment-navigation -->
        <?php endif; // check for comment navigation ?>
 
        <ol class="commentlist">
            <?php
                /* Loop through and list the comments. Tell wp_list_comments()
                 * to use aplos_comment() to format the comments.
                 * If you want to overload this in a child theme then you can
                 * define aplos_comment() and that will be used instead.
                 * See aplos_comment() in inc/template-tags.php for more.
                 */
                wp_list_comments( array( 'callback' => 'aplos_comment' ) );
            ?>
        </ol><!-- .commentlist -->
 
        <?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // are there comments to navigate through? If so, show navigation ?>
        <nav role="navigation" id="comment-nav-below" class="site-navigation comment-navigation">
            <h1 class="assistive-text"><?php _e( 'Навигация', 'aplos' ); ?></h1>
            <div class="nav-previous"><?php previous_comments_link( __( '&larr; Предыдущие комментарии', 'aplos' ) ); ?></div>
            <div class="nav-next"><?php next_comments_link( __( 'Следующие комментарии &rarr;', 'aplos' ) ); ?></div>
        </nav><!-- #comment-nav-below .site-navigation .comment-navigation -->
        <?php endif; // check for comment navigation ?>
 
    <?php endif; // have_comments() ?>
 
    <?php
        // If comments are closed and there are comments, let users know
        if ( ! comments_open() && '0' != get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) :
    ?>
        <p class="nocomments"><?php _e( 'Комментарии закрыты.', 'aplos' ); ?></p>
    <?php endif; ?>
 
    <?php comment_form(); ?>
 
</div><!-- #comments .comments-area -->